@@ -19,6 +19,7 @@ from .base import (
     fac_kline_day,
     fac_filter,
     fac_filter_notindex,
+    fac_components,
 )
 
 __all__ = [
@@ -32,4 +33,5 @@ __all__ = [
     "fac_kline_day",
     "fac_filter",
     "fac_filter_notindex",
+    "fac_components",
 ]
\ No newline at end of file
