@@ -13,11 +13,13 @@ from typing import Callable
 import logair
 import ygo
 
-logger = logair.get_logger("quda.dataset")
-
 def complete_data(fn, date, save_path):
+    logger = logair.get_logger("quda.dataset")
     try:
         data = fn(date=date)
+        if data is None:
+            # 保存数据的逻辑在fn中实现了
+            return
         # 剔除以 `_` 开头的列
         data = data.filter(date=date).select(~cs.starts_with("_"))
         if not isinstance(data, (pl.DataFrame, pl.LazyFrame)):
@@ -141,12 +143,12 @@ class Dataset:
                         save_path =save_path / f"{k}={v}"
                 fn = partial(self.fn, **params)
 
-            with ygo.pool(n_jobs=10) as go:
+            with ygo.pool(n_jobs=5, backend="loky") as go:
                 for date in missing_dates:
                     go.submit(complete_data, job_name=f"completing {self.save_path.relative_to(lidb.DB_PATH)}")(
                         fn=fn,
                         date=date,
                         save_path=save_path / f"date={date}", )
                 go.do()
-        data = lidb.scan(self.save_path, abs_path=True).filter(pl.col("date").is_in(dateList), **constraints)
+        data = lidb.scan(search_path, abs_path=True).filter(pl.col("date").is_in(dateList), **constraints)
         return data.sort("date").collect()
\ No newline at end of file
