@@ -58,8 +58,12 @@ def factor_context(func: callable, ):
         }
         if period:
             date = bound_args.arguments.get("date")
-            date_shifted, _ = xcals.shift_tradedt(date, self.end_time, period)
-            beg_date, end_date = min([date, date_shifted]), max([date, date_shifted])
+            beg_date = bound_args.arguments.get("beg_date")
+            if not beg_date:
+                date_shifted, _ = xcals.shift_tradedt(date, self.end_time, period)
+                beg_date, end_date = min([date, date_shifted]), max([date, date_shifted])
+            else:
+                beg_date, end_date = min([date, beg_date]), max([date, beg_date])
             filtered.update({"beg_date": beg_date, "end_date": end_date})
 
         ctx = FactorContext(**filtered)
@@ -338,7 +342,8 @@ class Factor:
     def get_history(self,
                     date,
                     codes: list[str] | None = None,
-                    period: str = '5d',
+                    period: str = '-5d',
+                    beg_date: str = None,
                     time='15:00:00',
                     avoid_future: bool = True,
                     show_progress: bool = True,
@@ -356,6 +361,8 @@ class Factor:
             时间，默认为'15:00:00', 格式 hh:mm:ss
         period: str
             回看周期, 最小单位为d, 小于d的周期向上取整，比如1d1s,视为2d
+        beg_date: str
+            开始日期，如果赋值，则period参数失去作用
         n_jobs : int, optional
             并发任务数，默认为7。
         avoid_future: bool
@@ -380,7 +387,8 @@ class Factor:
     def get_history_depends(self,
                             date,
                             codes: list[str] | None = None,
-                            period: str = '5d',
+                            period: str = '-5d',
+                            beg_date: str = None,
                             time="15:00:00",
                             avoid_future: bool = True,
                             show_progress: bool = True,
@@ -396,6 +404,8 @@ class Factor:
             股票代码列表，默认为 None。
         period: str
             回看周期, 最小单位为d, 小于d的周期向上取整，比如1d1s,视为2d
+        beg_date: str
+            开始日期，如果赋值，则period参数失去作用
         time : str
         show_progress : bool, optional
             是否显示进度条，默认为 True。
