@@ -40,7 +40,7 @@ def d_ref(expr: pl.Expr, windows, dims):  # return expr.shift(int(abs(windows)))
             .shift(windows)
             .to_numpy()
             .ravel(),
-            return_dtype=pl.self_dtype()
+            # return_dtype=pl.self_dtype()
         )
         .replace(np.nan, None)
     )
@@ -66,7 +66,7 @@ def d_rank(expr: pl.Expr, windows, dims):
             .drop("index")
             .to_numpy()
             .ravel(),
-            return_dtype=pl.self_dtype()
+            # return_dtype=pl.self_dtype()
         )
     )
 
@@ -84,7 +84,7 @@ def d_prod(expr: pl.Expr, windows, dims):
             .drop("index")
             .to_numpy()
             .ravel(),
-            return_dtype=pl.self_dtype()
+            # return_dtype=pl.self_dtype()
         )
     )
 
@@ -172,7 +172,7 @@ def d_entropy(expr: pl.Expr, windows, dims):
             .drop("index")
             .to_numpy()
             .ravel(),
-            return_dtype=pl.self_dtype()
+            # return_dtype=pl.self_dtype()
         )
     )
 
