@@ -12,7 +12,7 @@ from quda.data import DataLoader, DatasetLoader
 import quda
 import xcals
 from sklearn.pipeline import Pipeline
-from quda.data import transformer
+from quda.ml import transformer
 
 
 simple_loader = DataLoader(fn=lambda iter_date, ds_path: quda.sql(f"select * from {ds_path} where date='{iter_date}';"),
